A simulated auxiliary data to show how to use 'bndovbme' function with discrete proxy variables
auxdat_mediscA data frame with 3000 rows and 5 variables:
A common covariate in both main and auxiliary data
A common covariate in both main and auxiliary data
A discrete proxy variable
A discrete proxy variable
A discrete proxy variable