Learn R Programming

bndovb (version 1.1)

auxdat_nome: A simulated auxiliary data to show how to use 'bndovb' function

Description

A simulated auxiliary data to show how to use 'bndovb' function

Usage

auxdat_nome

Arguments

Format

A data frame with 50000 rows and 3 variables:

x1

An omitted variable in the main data

x2

A common covariate in both main and auxiliary data

x3

A common covariate in both main and auxiliary data