Learn R Programming

bndovb (version 1.1)

maindat_medisc: A simulated main data to show how to use 'bndovbme' function with discrete proxy variables

Description

A simulated main data to show how to use 'bndovbme' function with discrete proxy variables

Usage

maindat_medisc

Arguments

Format

A data frame with 3000 rows and 3 variables:

w1

A common covariate in both main and auxiliary data

x

A common covariate in both main and auxiliary data

y

A dependent variable