Learn R Programming

bndovb (version 1.1)

maindat_nome: A simulated main data to show how to use 'bndovb' function

Description

A simulated main data to show how to use 'bndovb' function

Usage

maindat_nome

Arguments

Format

A data frame with 100000 rows and 3 variables:

x2

A common covariate in both main and auxiliary data

x3

A common covariate in both main and auxiliary data

y

A dependent variable