powered by
A simulated auxiliary data to show how to use 'bndovb' function
auxdat_nome
A data frame with 50000 rows and 3 variables:
An omitted variable in the main data
A common covariate in both main and auxiliary data