powered by
A simulated main data to show how to use 'bndovb' function
maindat_nome
A data frame with 100000 rows and 3 variables:
A common covariate in both main and auxiliary data
A dependent variable